@@ -40,12 +40,12 @@ func (r *ReconcileHostPathProvisioner) reconcileSecurityContextConstraints(reqLo
 	}
 
 	// Define a new SecurityContextConstraints object
-	desired := createSecurityContextConstraintsObject(cr, namespace)
+	desired := createSecurityContextConstraintsObject(namespace)
 	setLastAppliedConfiguration(desired)
 
 	// Check if this SecurityContextConstraints already exists
 	found := &secv1.SecurityContextConstraints{}
-	err := r.client.Get(context.TODO(), types.NamespacedName{Name: cr.Name}, found)
+	err := r.client.Get(context.TODO(), types.NamespacedName{Name: MultiPurposeHostPathProvisionerName}, found)
 	if err != nil && errors.IsNotFound(err) {
 		reqLogger.Info("Creating a new SecurityContextConstraints", "SecurityContextConstraints.Name", desired.Name)
 		recorder.Event(cr, corev1.EventTypeNormal, createResourceStart, fmt.Sprintf(createMessageStart, desired, desired.Name))
@@ -92,27 +92,28 @@ func (r *ReconcileHostPathProvisioner) reconcileSecurityContextConstraints(reqLo
 	return reconcile.Result{}, nil
 }
 
-func (r *ReconcileHostPathProvisioner) deleteSCC(cr *hostpathprovisionerv1.HostPathProvisioner) error {
+func (r *ReconcileHostPathProvisioner) deleteSCC(name string) error {
 	if used, err := r.checkSCCUsed(); used == false {
 		return err
 	}
 	// Check if this SecurityContextConstraints already exists
-	scc := &secv1.SecurityContextConstraints{}
-	err := r.client.Get(context.TODO(), types.NamespacedName{Name: cr.Name}, scc)
-	if err != nil && errors.IsNotFound(err) {
-		// Already gone, return
-		return nil
-	} else if err != nil {
+	scc := &secv1.SecurityContextConstraints{
+		ObjectMeta: metav1.ObjectMeta{
+			Name: name,
+		},
+	}
+
+	if err := r.client.Delete(context.TODO(), scc); err != nil && !errors.IsNotFound(err) {
 		return err
 	}
-	// Delete SCC
-	return r.client.Delete(context.TODO(), scc)
+
+	return nil
 }
 
-func createSecurityContextConstraintsObject(cr *hostpathprovisionerv1.HostPathProvisioner, namespace string) *secv1.SecurityContextConstraints {
-	saName := fmt.Sprintf("system:serviceaccount:%s:%s-admin", namespace, cr.Name)
+func createSecurityContextConstraintsObject(namespace string) *secv1.SecurityContextConstraints {
+	saName := fmt.Sprintf("system:serviceaccount:%s:%s", namespace, ControllerServiceAccountName)
 	labels := map[string]string{
-		"k8s-app": cr.Name,
+		"k8s-app": MultiPurposeHostPathProvisionerName,
 	}
 	return &secv1.SecurityContextConstraints{
 		Groups: []string{},
@@ -121,7 +122,7 @@ func createSecurityContextConstraintsObject(cr *hostpathprovisionerv1.HostPathPr
 			Kind:       "SecurityContextConstraints",
 		},
 		ObjectMeta: metav1.ObjectMeta{
-			Name:   cr.Name,
+			Name:   MultiPurposeHostPathProvisionerName,
 			Labels: labels,
 		},
 		AllowPrivilegedContainer: false,
